<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>CreateLibraryItem</name>
    <message>
        <location filename="../CreateLibraryItem.js" line="+49"/>
        <source>Reference Point</source>
        <translation>Point de référence</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Save library item as...</source>
        <translation>Enregistrer élément de bibliothèque...</translation>
    </message>
    <message>
        <location filename="../CreateLibraryItemInit.js" line="+2"/>
        <source>&amp;Create Library Item</source>
        <translation>&amp;Créer élément de bibliothèque</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Create library item from selection</source>
        <translation>Créer élément de la bibliothèque à partir de la sélection</translation>
    </message>
</context>
</TS>
